@@ -1,9 +1,11 @@
+import sys
 import time
 from fastutil.tool import gpu_util, loguru_util, logging_util, message_util, git_util, task_plan
 from fastutil.model import model_util
 from loguru import logger
 from fastutil.data import cleaner
 import argparse
+from multiprocessing import Pool
 
 
 def test_util():
@@ -31,7 +33,7 @@ def test_clean():
 
 
 @logger.catch()
-@model_util.log_record(config_module=logging_util, save_dir='log/' + git_util.get_ver_id(), check_commit=False)
+# @model_util.log_record(config_module=logging_util, save_dir='log/' + git_util.get_ver_id(), check_commit=False)
 def test_task():
     parser = argparse.ArgumentParser(description='使用示例：taskkill train.py')
     parser.add_argument('name', nargs='*', help='进程grep标记')
@@ -41,5 +43,13 @@ def test_task():
     raise Exception('gg')
 
 
+def log(v):
+    with logger.contextualize(ID=v):
+        time.sleep(0.3)
+        logger.info(v)
+
+
 if __name__ == '__main__':
-    test_task()
+    loguru_util.add_path('log/nohup.log', trace_id='ID')
+    with Pool(3) as pool:
+        pool.map(log, range(100))
